;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "ledger-mode" "20250821.1439"
  "Helper code for use with the \"ledger\" command-line tool."
  '((emacs "26.1"))
  :url "https://github.com/ledger/ledger-mode"
  :commit "e9bb645e8f05cf7ad0819b0450db7e84c9ed3f41"
  :revdesc "e9bb645e8f05")
